# [Zope-tests] OK : winbot / ZODB_dev py_270_win64

buildbot at winbot.zope.org buildbot at winbot.zope.org
Tue Feb 1 22:04:15 EST 2011

- Previous message: [Zope-tests] OK : Bluebream / Python2.5.5 64bit linux
- Next message: [Zope-tests] FAILED : winbot / z3c.rml_py_265_32
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]

    OK : winbot / ZODB_dev py_270_win64
    Build: http://winbot.zope.org/builders/ZODB_dev%20py_270_win64/builds/195

    Build Reason: The Nightly scheduler named 'ZODB_dev py_270_win64_nightly' triggered this build

    Build Source Stamp: HEAD

    Blamelist:

    Buildbot: http://winbot.zope.org/

- Previous message: [Zope-tests] OK : Bluebream / Python2.5.5 64bit linux
- Next message: [Zope-tests] FAILED : winbot / z3c.rml_py_265_32
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]

More information about the Zope-tests mailing list